package com.edgec.browserbackend.account.domain;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import org.hibernate.validator.constraints.Length;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Document(collection = "accounts")
@JsonIgnoreProperties(ignoreUnknown = true)
public class Account {

    @Id
    private String name;

    private String parent;

    private Date lastSeen;

    private Date signupDate = new Date();

    private String email;

    private String companyName;

    private String jobTitle;

    private String phoneNumber;

    private String lockReason;

    private boolean isPrePaid = true;

    private String token;

    private boolean allowedToCreateSubUser = false;

    private boolean hasOperationRight = false;

    public Date getSignupDate() {
        return signupDate;
    }

    public void setSignupDate(Date signupDate) {
        this.signupDate = signupDate;
    }

    public boolean isPrePaid() {
        return isPrePaid;
    }

    public void setPrePaid(boolean prePaid) {
        isPrePaid = prePaid;
    }

    public Account() {
    }

    public Account(AccountDto account) {
        this.setName(account.getName());
        this.setAllowedToCreateSubUser(account.isAllowedToCreateSubUser());
        this.setCompanyName(account.getCompanyName());
        this.setEmail(account.getEmail());
        this.setJobTitle(account.getJobTitle());
        this.setPhoneNumber(account.getPhoneNumber());
        this.setHasOperationRight(account.isHasOperationRight());
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getJobTitle() {
        return jobTitle;
    }

    public void setJobTitle(String jobTitle) {
        this.jobTitle = jobTitle;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    @Length(min = 0, max = 20000)
    private String note;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getLastSeen() {
        return lastSeen;
    }

    public void setLastSeen(Date lastSeen) {
        this.lastSeen = lastSeen;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getParent() {
        return parent;
    }

    public void setParent(String parent) {
        this.parent = parent;
    }

    public boolean isAllowedToCreateSubUser() {
        return allowedToCreateSubUser;
    }

    public void setAllowedToCreateSubUser(boolean allowedToCreateSubUser) {
        this.allowedToCreateSubUser = allowedToCreateSubUser;
    }

    public String getLockReason() {
        return lockReason;
    }

    public void setLockReason(String lockReason) {
        this.lockReason = lockReason;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public boolean isHasOperationRight() {
        return hasOperationRight;
    }

    public void setHasOperationRight(boolean hasOperationRight) {
        this.hasOperationRight = hasOperationRight;
    }
}
